@@ -1,3 +1,5 @@
+import numpy as np
+
 import opytimark.utils.exception as e
 
 
@@ -23,6 +25,15 @@ def check_dimension(f):
         # Retrieving the object and the input from arguments
         obj, x = args[0], args[1]
 
+        # Tries to squeeze the last dimension of `x` as it might be an array of (dim, 1)
+        try:
+            # Squeezes the array
+            x = np.squeeze(x, axis=1)
+        
+        # If squeeze could not be performed, it means that there is no extra dimension
+        except:
+            pass
+
         # If the function's number of dimensions is equal to `-1` (n-dimensional)
         if obj.dims == -1:
             # Checks if the input array is bigger than zero
@@ -30,13 +41,13 @@ def check_dimension(f):
                 # If not, raises an error
                 raise e.SizeError(f'{obj.name} input should be n-dimensional')
 
-            return f(*args)
+            return f(obj, x)
 
         # If the input dimensions is different from function's allowed dimensions
         if x.shape[0] != obj.dims:
             # Raises an error
             raise e.SizeError(f'{obj.name} input should be {obj.dims}-dimensional')
 
-        return f(*args)
+        return f(obj, x)
 
     return _check_dimension
